# pydoodle
An API wrapper of online compiler jdoodle.com written in python.


## Features
 - Easy to use.
 - Over 50+ languages to compile.
 - Get the credits spent information.


## How to install?
Use the following command on you device to install it.
```
pip install pydoodle
```

### Documentation
 - Documentaion is hosted on [pydoodle.readthedocs.io](https://pydoodle.readthedocs.io) (Under development, contributions are appreciated)

### Example
 - A basic [example](examples/example.py) on how to use this package.


### Misc 
 - Star this repo if you're using this wrapper 😄
 - Head over to [jdoodle](https://jdoodle.com/compiler-api) to get clientId and clientSecret.
 - Read the FAQs of the API [here.](https://docs.jdoodle.com/compiler-api/compiler-api)

#### Facing any Issue?
 - Feel free to [create an issue.](https://github.com/Prince2347X/pydoodle/issues/new)
